#
#       HBS REDUCTION SUB ROUTINE
#
#        magnitude binning and make polarized flux table : hbsphbin.cl
#
#       1998/07/31      K.Kawabata  Ver.2.00
#       1998/09/28      K.Kawabata  Ver.2.10
#       2005/04/07      M.Isogai    Ver.2.20 for iraf v2.12
#

procedure hbsphbin( inimage, intable, inerror, ref_bin, outimage, outtable )

file inimage { prompt = "Input image of unbinned magnutude" }
file intable { prompt = "Input table (made by hbsmktable)" }
file inerror { prompt = "Input image of binned error fraction (none='n')" }
file ref_bin { prompt = "Binning factor table" }
file outimage { prompt = "Output image of binned magnitude" }
file outtable { prompt = "Output table" }

begin

  file infn, outfn
  file inerr
  file intab, outtab
  file reffn, fnphot
  string tmp_fn1, tmp_fn2, tmp_fn3
  string buf1, buf2
  string refdir # filter table site

  int c

  int n_version      # IRAF version (210 or 211)


#--- initial settings

  tmp_fn1 = mktemp( "hbs.tmp.fn." )
  tmp_fn2 = mktemp( "hbs.tmp.fn." )
  tmp_fn3 = mktemp( "hbs.tmp.fn." )

  infn = inimage
  intab = intable
  inerr = inerror
  reffn = ref_bin
  outfn = outimage
  outtab = outtable

  refdir = envget( "_etcdir" )
  fnphot = envget( "_caldir" )//envget( "_photmet" )

#----- IRAF version check

  buf1 = envget( "version" )
  c = stridx( "V", buf1 )
  buf2 = substr( buf1, c, ( c + 4 ) )

  n_version = 0

  if( buf2 == "V2.11" || buf2 == "V2.12" )
  {
    n_version = 211
  }
  else
  {
    if( buf2 == "V2.10" )
    {
      n_version = 210
    }
  }

  if( n_version == 0 )
  {
    printf( "IRAF version check failed.\n" )
    printf( "Please input like next line, and restart 'hbsred'\n"
    printf( "cl> set version V2.10  (V2.10 and V2.11 are valid)\n"
    bye
  }

  if( inerr == "n" || inerr == "none" )
  {
    imcopy( infn, tmp_fn3, ver- )
    imreplace( tmp_fn3, 0.0 )
  }

#--- main

  if( n_version == 210 )
  { 
    wfits( infn//".imh", tmp_fn1, bscale=1.0, bzero=0.0, long_header-,
           short_header-, bitpix=-32, scale-, autoscale- )
    if( inerr == "n" || inerr == "none" )
    {
      wfits( tmp_fn3//".imh", tmp_fn3, bscale=1.0, bzero=0.0, long_header-,
             short_header-, bitpix=-32, scale-, autoscale- )
    }
    else
    {
      wfits( inerr//".imh", tmp_fn3, bscale=1.0, bzero=0.0, long_header-,
             short_header-, bitpix=-32, scale-, autoscale- )
    }
  }
  else
  {
    wfits( infn//".imh", tmp_fn1, bscale=1.0, bzero=0.0, long_header-,
           fextn="", short_header-, bitpix=-32, scale-, autoscale- )
    if( inerr == "n" || inerr == "none" )
    {
      wfits( tmp_fn3//".imh", tmp_fn3, bscale=1.0, bzero=0.0, long_header-,
             fextn="", short_header-, bitpix=-32, scale-, autoscale- )
    }
    else
    {
      wfits( inerr//".imh", tmp_fn3, bscale=1.0, bzero=0.0, long_header-,
             fextn="", short_header-, bitpix=-32, scale-, autoscale- )
    }
  }

  copy( tmp_fn1, tmp_fn2, ver- )
  hbscbin( tmp_fn1, reffn, refdir, fnphot, tmp_fn2, "2" )

  if( access( outfn//".imh" ) == 1 )
    imdelete( outfn, ver- )

  if( n_version == 210 )
  {
    rfits( tmp_fn2, "", outfn, make_image+, long_header-, short_header-,\
           datatype="real", blank=0., scale-, oldirafname-, offset=0 )
  }
  if( n_version == 211 )
  {
    rfits( tmp_fn2, "", outfn//".imh", make_image+, long_header-,\
           short_header-,\
           datatype="real", blank=0., scale-, oldirafname-, offset=0 )
  }

  delete( tmp_fn1, ver- )
  if( inerr == "n" || inerr == "none" )
    imdelete( tmp_fn3, ver- )

  hbsipol( intab, tmp_fn2, tmp_fn3, outtab )

  delete( tmp_fn2, ver- )
  delete( tmp_fn3, ver- )

end
