#
#       HBS REDUCTION SUB ROUTINE
#
#       Grouping photometric images : hbsphgroup.cl
#
#       2000/02/20      K.Kawabata   ver 3.00  unification
#

procedure hbsphgroup

begin

  int i, j
  int c
  file phlist
  string fn_stack[100], fn_stddat[100]
  int flag_std[100]
  int n_list
  file tmp_list
  
  file specref = "HBS.phot.refspec"
  real am

  string stddat[100]
  int n_std

  string buf
  
  print( "" )
  print( "-----------------------------" )
  print( " Grouping photometric images" )
  print( "-----------------------------" )
  print( "" )

  phlist = envget( "_phlist" )
  tmp_list = mktemp( "hbs.tmp.list." )

#----- Search data tables of standard star

  if( access( tmp_list ) == 1 )
    delete( tmp_list, ver- )

  chdir _stddir$
  sections( "*.dat", option="fullname", > tmp_list )
  if( sections.nimages == 0 )
  {
    printf( "No data of spectrophotometric standards.\n" )
    back
    bye
  }
  n_std = 0
  list = tmp_list
  while( fscan( list, buf ) != EOF )
  {
    n_std += 1
    stddat[n_std] = buf
  }
  delete( tmp_list, ver- )
  back

#----- Search flux images

  if( access( tmp_list ) == 1 )
    delete( tmp_list, ver- )

  sections( "*i2.ave.imh", option="fullname", > tmp_list )
  if( sections.nimages == 0 )
  {
    printf( "No I2-spectral image found in this directory.\n" )
    delete( tmp_list, ver- )
    bye
  }

  n_list = 0
  list = tmp_list
  while( fscan( list, buf ) != EOF )
  {
    n_list += 1
    fn_stack[n_list] = buf
    flag_std[n_list] = 0
    fn_stddat[n_list] = ""
  }
  delete( tmp_list, ver- )

#----- Delete old list

  if( access( phlist ) == 1 )
  {
    printf( "There is old photometry list.  delete ? (y/n)  >> " )
    c = scan( buf )
    while( buf != "y" && buf != "n" )
       c = scan( buf )
    if( buf == "y" )
      delete( phlist )
    else
    {
      print( "OK. continue refering these files." )
      goto makerefimage
    }
  }


showallimages:
  print( "These flux images are found..." )
  for( i=1; i<=n_list; i+=1 )
  {
    if( flag_std[i] == 0 )
      printf( "%2d  %s\n", i, fn_stack[i] )
    else
      printf( "%2d  %s  ref. %s\n", i, fn_stack[i], fn_stddat[i] )
  }
  i = -1
  printf( "\nInput number of standard image [0: end] >> " )
  c = scan( i )
  while( i < 0 || i > n_list )
    c = scan( i )
  if( i > 0 )
  {
    printf( "Select data file number for %s >> ", fn_stack[i] )
    for( j=1; j<=n_std; j+=1 )
    {
      printf( "%2d  %s\n", j, stddat[j] )
    }
    j = -1
    printf( "\nInput number of data table [0: return] >> " )
    c = scan( j )
    while( j < 0 || j > n_std )
      c = scan( j )
    if( j == 0 )
      goto showallimages
    fn_stddat[i] = stddat[j]
    flag_std[i] = 1
    goto showallimages
  }

makerefimage:
#----- make reference image

  if( access( specref//".imh" ) == 1 )
  {
    printf( "Old spectral reference image exists. Erase this? [y/n] >> " )
    c = scan( buf )
    while( buf != "y" && buf != "n" )
       c = scan( buf )
    if( buf == "y" )
    {
      imdelete( specref, ver- )
    }
    else
      goto ending
  }

  #--- select reference image

  if( access( tmp_list ) == 1 )
    delete( tmp_list, ver- )

  for( i=1; i<=n_list; i+=1 )
  {
    imgets( fn_stack[i], "AIRMASS" )
    am = real( imgets.value )
    printf( "%2d  %15s (airmass %5.3f)\n", i, fn_stack[i], am )
  }
  printf( "---------------------------------------\n" )
  while( i != 0 )
  {
    printf( "Select number of reference ([0]: average) >> " )
    c = scan( i )
    while( i < 0 || i > n_list )
       c = scan( i )
    if( i == 0 )
      next
    printf( "%s\n", fn_stack[i], >> tmp_list )
  }

  printf( "Now modifying reference image %s... ", specref )
  imsum( "@"//tmp_list, specref, pixtype="real", calctype="real",\
         option="average", ver- )
  delete( tmp_list, ver- )

#  printf( "\n[x]-[x]: smoothing [i]:write current image [q]:quit\n" )
#  splot( specref )
#  boxcar( specref, specref, 15, 1 )
   imreplace( specref, 1.0 )

#----- make list file

  for( i=1; i<=n_list; i+=1 )
  {
    if( flag_std[i] == 1 )
      printf( "%s  %s\n", fn_stack[i], fn_stddat[i], >> phlist )
  }

ending:

  printf( "\n********** gropuint done ***********\n" )
  type( phlist )
  printf(   "************************************\n\n" )

end
